@@ -215,13 +215,12 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
         self.find(str)
     
     def findPrev(self, str):
-        self.find(str, QtWidgets.QTextDocument.FindBackward)
+        self.find(str, QtGui.QTextDocument.FindBackward)
 
     def replaceNext(self, strA, strB):
         if self.find(strA):
             curs = self.textCursor()
             curs.insertText(strB)
-            
             curs.movePosition(QtGui.QTextCursor.StartOfBlock, QtGui.QTextCursor.MoveAnchor)
             self.setTextCursor(curs)
             self.find(strB)
@@ -384,12 +383,25 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
     def keyPressEvent(self, event):
         ok = 1
 
-        if len(self.textCursor().selectedText()) and event.key() == 16777218:
-            self.indent("left")
-            return
-        if len(self.textCursor().selectedText()) and event.key() == QtCore.Qt.Key_Tab:
-            self.indent("right")
-            return
+        if len(self.textCursor().selectedText()):
+            if event.key() == 16777218:
+                self.indent("left")
+                return
+            if event.key() == QtCore.Qt.Key_Tab:
+                self.indent("right")
+                return
+        else:
+            if event.key() == QtCore.Qt.Key_Backspace:
+                curs = self.textCursor()
+                spos = curs.positionInBlock()
+                count = 0
+                while curs.block().text()[spos-count-1:spos-count] == ' ':
+                    count += 1
+                if spos-count == 0:
+                    count = 4 if count % 4 == 0 else count % 4
+                    for i in range(count):
+                        curs.deletePreviousChar()
+                    return
         
         if self.completer:
             if self.completer.popup().isVisible():
@@ -416,7 +428,7 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
 
         # ctrl or shift key on it's own??
         ctrlOrShift = event.modifiers() in (QtCore.Qt.ControlModifier, QtCore.Qt.ShiftModifier)
-        if ctrlOrShift and str(event.text()) == '':
+        if ctrlOrShift and len(event.text()) == 0:
             # ctrl or shift key on it's own
             return
 
